@@ -23,12 +23,12 @@
 #' }
 #' @export
 dominance_graph <- function(P) {
-  if (!inherits(P, "Matrix") & !is.matrix(P)) {
-    stop("P must be a dense or spare matrix")
-  }
-  if (!is.binary(P)) {
-    stop("P is not a binary matrix")
-  }
-  d <- igraph::graph_from_adjacency_matrix(P, "directed")
-  return(d)
+    if (!inherits(P, "Matrix") && !is.matrix(P)) {
+        stop("P must be a dense or spare matrix")
+    }
+    if (!is.binary(P)) {
+        stop("P is not a binary matrix")
+    }
+    d <- igraph::graph_from_adjacency_matrix(P, "directed")
+    return(d)
 }
