@@ -17,33 +17,33 @@
 #' @export
 
 get_rankings <- function(data, force = FALSE) {
-  if (!"netrankr_full" %in% class(data)) {
-    stop("data is not a netrankr_full object")
-  }
+    if (!"netrankr_full" %in% class(data)) {
+        stop("data is not a netrankr_full object")
+    }
 
-  if (is.null(data$tree)) {
-    stop("input does not include all necessary data structures. run exact_rank_prob() with 'only.results = FALSE'")
-  }
-  lattice <- data$lattice
-  ideals <- data$ideals
-  topo.order <- data$topo.order
-  linext <- data$lin.ext
-  mse <- data$mse
+    if (is.null(data$tree)) {
+        stop("input does not include all necessary data structures. run exact_rank_prob() with 'only.results = FALSE'")
+    }
+    lattice <- data$lattice
+    ideals <- data$ideals
+    topo.order <- data$topo.order
+    linext <- data$lin.ext
+    mse <- data$mse
 
-  if (linext > 50000 & !force) {
-    stop("number of possible rankings is very high. Use 'force = FALSE'
+    if (linext > 50000 && !force) {
+        stop("number of possible rankings is very high. Use 'force = FALSE'
            if you know what you are doing.")
-  }
+    }
 
-  n <- length(unique(mse))
-  lattice <- lapply(lattice, function(x) x + 1)
-  g <- igraph::graph_from_adj_list(lattice, mode = "in")
-  paths <- igraph::all_shortest_paths(g, from = n + 1, to = 1)
+    n <- length(unique(mse))
+    lattice <- lapply(lattice, function(x) x + 1)
+    g <- igraph::graph_from_adj_list(lattice, mode = "in")
+    paths <- igraph::all_shortest_paths(g, from = n + 1, to = 1)
 
-  paths <- lapply(paths$res, function(x) as.vector(x) - 1)
-  rks <- rankings(paths, ideals, linext, n)
-  rks <- rks + 1
-  rks <- rks[order(topo.order), ]
-  rks <- rks[mse, ]
-  return(rks)
+    paths <- lapply(paths$res, function(x) as.vector(x) - 1)
+    rks <- rankings(paths, ideals, linext, n)
+    rks <- rks + 1
+    rks <- rks[order(topo.order), ]
+    rks <- rks[mse, ]
+    return(rks)
 }
